import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'
import ParentView from '@/components/ParentView';

/**
 * Note: 路由配置项
 *
 * hidden: true                   // 当设置 true 的时候该路由不会再侧边栏出现 如401，login等页面，或者如一些编辑页面/edit/1
 * alwaysShow: true               // 当你一个路由下面的 children 声明的路由大于1个时，自动会变成嵌套的模式--如组件页面
 *                                // 只有一个时，会将那个子路由当做根路由显示在侧边栏--如引导页面
 *                                // 若你想不管路由下面的 children 声明的个数都显示你的根路由
 *                                // 你可以设置 alwaysShow: true，这样它就会忽略之前定义的规则，一直显示根路由
 * redirect: noRedirect           // 当设置 noRedirect 的时候该路由在面包屑导航中不可被点击
 * name:'router-name'             // 设定路由的名字，一定要填写不然使用<keep-alive>时会出现各种问题
 * meta : {
    noCache: true                // 如果设置为true，则不会被 <keep-alive> 缓存(默认 false)
    title: 'title'               // 设置该路由在侧边栏和面包屑中展示的名字
    icon: 'svg-name'             // 设置该路由的图标，对应路径src/assets/icons/svg
    breadcrumb: false            // 如果设置为false，则不会在breadcrumb面包屑中显示
  }
 */

// 公共路由
export const constantRoutes = [
  {
    path: '/redirect',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '/redirect/:path(.*)',
        component: (resolve) => require(['@/views/redirect'], resolve)
      }
    ]
  },
  {
    path: '/login',
    component: (resolve) => require(['@/views/tester_login'], resolve),
    hidden: true
  },
  {
    path: '/register',
    component: (resolve) => require(['@/views/register'], resolve),
    hidden: true
  },
  {
    path: '/retrieve',
    component: (resolve) => require(['@/views/retrieve'], resolve),
    hidden: true
  },
  {
    path: '/tl',
    component: (resolve) => require(['@/views/tester_login'], resolve),
    hidden: true
  },
  {
    path: '/404',
    component: (resolve) => require(['@/views/error/404'], resolve),
    hidden: true
  },
  {
    path: '/401',
    component: (resolve) => require(['@/views/error/401'], resolve),
    hidden: true
  },
  {
    path: '',
    component: Layout,
    redirect: 'index',
    children: [
      {
        path: 'index',
        component: (resolve) => require(['@/views/index'], resolve),
        name: '首页',
        meta: { title: '首页', icon: 'dashboard', noCache: true, affix: true }
      }
    ]
  },
  {
    path: '/user',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    children: [
      {
        path: 'profile',
        component: (resolve) => require(['@/views/system/user/profile/index'], resolve),
        name: 'Profile',
        meta: { title: '个人中心', icon: 'user' }
      },
      {
        path: 'profile/:activeTab',
        component: (resolve) => require(['@/views/system/user/profile/index'], resolve),
        name: 'Profile',
        meta: { title: '个人中心', icon: 'user' }
      },
      {
        path: 'company',
        component: (resolve) => require(['@/views/system/user/company/index'], resolve),
        name: 'company',
        meta: { title: '企业认证', icon: 'user' }
      },
      {
        path: 'p2pt',
        component: (resolve) => require(['@/views/system/user/tester/p2pt'], resolve),
        name: 'tester',
        meta: { title: '测试资质认证', icon: 'user' }
      },
      {
        path: 'p2ct',
        component: (resolve) => require(['@/views/system/user/tester/p2ct'], resolve),
        name: 'tester',
        meta: { title: '测试资质认证', icon: 'user' }
      },
      {
        path: 'c2ct',
        component: (resolve) => require(['@/views/system/user/tester/c2ct'], resolve),
        name: 'tester',
        meta: { title: '测试资质认证', icon: 'user' }
      },
      {
        path: 'message',
        component: (resolve) => require(['@/views/my/message'], resolve),
        name: 'MyMessage',
        meta: { title: '我的消息', icon: 'user' }
      }
    ]
  },
  {
    path: '/dict',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'type/data/:dictId(\\d+)',
        component: (resolve) => require(['@/views/system/dict/data'], resolve),
        name: 'Data',
        meta: { title: '字典数据', icon: '' }
      }
    ]
  },
  {
    path: '/my',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'tool/detail/:id(\\d+)',
        component: (resolve) => require(['@/views/mytools/detail'], resolve),
        name: 'myToolDetail',
        meta: { title: '我的工具详情', icon: '' }
      }
    ]
  },

  {
    path: '/test',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'tool/detail/:id(\\d+)',
        component: (resolve) => require(['@/views/market/detail'], resolve),
        name: 'MarketDetail',
        meta: { title: '测试工具详情', icon: '' }
      }
    ]
  },
  {
    path: '/crowdsource',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'my/publishApply/:id(\\d+)',
        component: (resolve) => require(['@/views/crowdsource/my/publishApply/detail'], resolve),
        name: 'crowdsourceAuditDetail',
        meta: { title: '我发布的众包审核历史', icon: '' }
      },
      {
        path: 'my/publish/:id(\\d+)',
        component: (resolve) => require(['@/views/crowdsource/my/publish/detail'], resolve),
        name: 'crowdsourcePublishDetail',
        meta: { title: '我发布的众包任务详情', icon: '' }
      },
      {
        path: 'my/claim/:id(\\d+)',
        component: (resolve) => require(['@/views/crowdsource/my/claim/detail'], resolve),
        name: 'crowdsourceClaimDetail',
        meta: { title: '我应征的众包任务详情', icon: '' }
      },
      {
        path: 'detail/:id(\\d+)',
        component: (resolve) => require(['@/views/crowdsource/detail'], resolve),
        name: 'myCrowdsourceDetail',
        meta: { title: '众包任务详情', icon: '' }
      },
      {
        path: 'manage/detail/:id(\\d+)',
        component: (resolve) => require(['@/views/manage/crowdsource/detail'], resolve),
        name: 'manageDetail',
        meta: { title: '众包任务详情', icon: '' }
      }
    ]
  },
  {
    path: '/buy',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'alipay',
        component: (resolve) => require(['@/views/market/buy/alipay'], resolve),
        name: 'alipay',
        meta: { title: '支付宝支付', icon: '' }
      }
    ]
  },
  {
    path: '/callback',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '',
        component: (resolve) => require(['@/views/market/buy/return'], resolve),
        name: 'return',
        meta: { title: '支付结果', icon: '' }
      }
    ]
  },
  {
    path: '/buy',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'tool/:id(\\d+)',
        component: (resolve) => require(['@/views/market/buy/alipay'], resolve),
        name: 'buyTool',
        meta: { title: '购买工具', icon: '' }
      }
    ]
  },
  
  //     {
  //       path: '/signInInfoList',
  //       component: (resolve) => require(['@/views/trainService/courseManageCom/signInInfoList.vue'], resolve),
  //       name: 'signInList',
  //       meta: { title: '签到详情', icon: '' }
   
  // },
  {
    path: '/job',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'log',
        component: (resolve) => require(['@/views/monitor/job/log'], resolve),
        name: 'JobLog',
        meta: { title: '调度日志' }
      }
    ]
  },
  {
    path: '/gen',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'edit/:tableId(\\d+)',
        component: (resolve) => require(['@/views/tool/gen/editTable'], resolve),
        name: 'GenEdit',
        meta: { title: '修改生成配置' }
      }
    ]
  }
]

export default new Router({
  // mode: 'hash', // 去掉url中的#
  mode: 'history', // 去掉url中的#
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})
